@@ -192,7 +192,7 @@ def to_sphinx(value):
 class SphinxQuerySet(object):
     available_kwargs = ('rankmode', 'mode', 'weights', 'maxmatches', 'passages', 'passages_opts')
     
-    def __init__(self, model=None, **kwargs):
+    def __init__(self, model=None, using=None, **kwargs):
         self._select_related        = False
         self._select_related_args   = {}
         self._select_related_fields = []
@@ -214,10 +214,12 @@ class SphinxQuerySet(object):
         self._result_cache          = None
         self._mode                  = sphinxapi.SPH_MATCH_ALL
         self._rankmode              = getattr(sphinxapi, 'SPH_RANK_PROXIMITY_BM25', None)
-        self.model                 = model
+        self.model                  = model
         self._anchor                = {}
         self.__metadata             = {}
         
+        self.using                  = using
+        
         options = self._format_options(**kwargs)
         for key, value in options.iteritems():
             setattr(self, key, value)
@@ -276,8 +278,11 @@ class SphinxQuerySet(object):
         kwargs = dict([('_%s' % (key,), value) for key, value in kwargs.iteritems() if key in self.available_kwargs])
         return kwargs
 
-    def get_query_set(self):
-        return self.model.objects.all()
+    def get_query_set(self, model):
+        qs = model._default_manager
+        if self.using:
+            qs = qs.db_manager('bth')
+        return qs.all()
 
     def set_options(self, **kwargs):
         kwargs = self._format_options(**kwargs)
@@ -543,7 +548,7 @@ class SphinxQuerySet(object):
             
         if self.model:
             if results['matches']:
-                queryset = self.get_query_set()
+                queryset = self.get_query_set(self.model)
                 if self._select_related:
                     queryset = queryset.select_related(*self._select_related_fields, **self._select_related_args)
                 if self._extra:
@@ -599,9 +604,9 @@ class SphinxQuerySet(object):
                                 objcache[ct][r['id']] = r['id'] = val
                     
                         q = reduce(operator.or_, [reduce(operator.and_, [Q(**{p.name: r['attrs'][p.column]}) for p in pks]) for r in results['matches'] if r['attrs']['content_type'] == ct])
-                        queryset = model_class.objects.filter(q)
+                        queryset = self.get_query_set(model_class).filter(q)
                     else:
-                        queryset = model_class.objects.filter(pk__in=[r['id'] for r in results['matches'] if r['attrs']['content_type'] == ct])
+                        queryset = self.get_query_set(model_class).filter(pk__in=[r['id'] for r in results['matches'] if r['attrs']['content_type'] == ct])
 
                     for o in queryset:
                         objcache[ct][', '.join([unicode(getattr(o, p.name)) for p in pks])] = o
@@ -665,6 +670,7 @@ class SphinxModelManager(object):
 
 class SphinxInstanceManager(object):
     """Collection of tools useful for objects which are in a Sphinx index."""
+    # TODO: deletion support
     def __init__(self, instance, index):
         self._instance = instance
         self._index = index
@@ -674,15 +680,16 @@ class SphinxInstanceManager(object):
         sphinxapi.UpdateAttributes(self._index, kwargs.keys(), dict(self.instance.pk, map(to_sphinx, kwargs.values())))
 
 class SphinxSearch(object):
-    def __init__(self, index=None, **kwargs):
+    def __init__(self, index=None, using=None, **kwargs):
         self._kwargs = kwargs
         self._sphinx = None
         self._index = index
         self.model = None
+        self.using = using
     
     def __call__(self, index, **kwargs):
         warnings.warn('For non-model searches use a SphinxQuerySet instance.', DeprecationWarning)
-        return SphinxQuerySet(index=index, **kwargs)
+        return SphinxQuerySet(index=index, using=self.using, **kwargs)
     
     def __get__(self, instance, model, **kwargs):
         if instance:
@@ -759,7 +766,7 @@ class SphinxRelation(SphinxSearch):
                     ids.append(value)
                 else:
                     ids.extend()
-            qs = self.get_query_set().filter(pk__in=set(ids))
+            qs = self.get_query_set(self.model).filter(pk__in=set(ids))
             if self._select_related:
                 qs = qs.select_related(*self._select_related_fields,
                                        **self._select_related_args)
